# Shear wall geometry input

# Created 08/07/2019 by A. Chatzidaki & D. Vamvatsikos

#--------------------------------------------------------
# Shear Wall geometry
# wall section length
set cwlen [expr 5.3*$m]

#wall section width
set cwb [expr 0.3*$m]

#wall section unconfined length (segment in the middle)
set cwlu [expr 13.*0.3*$m]

# cover
set cwc [expr 0.03*$m]

# Number of stories
set Nstory 7

#Store story heights in array. Case where 1st story has different height taken into account
set fsheight [expr 5.*$m]  ; #height of the 1st story
set sheight [expr 4.*$m] ; #height of the rest of the stories

set storyHeight " "

for {set i 1} {$i<=$Nstory} {incr i} {
  if {$i==1} {
		lappend storyHeight $fsheight 
  } else {
		lappend storyHeight $sheight 
  }
}


# Generate floormass array
set tribmass [expr (127330.)*$kg] ; # 127330 kg for each floor. 
set floormass " "

for {set i 1} {$i<=$Nstory} {incr i} {
	lappend floormass $tribmass
}



# if 1, then first floor columns are fixed at ground, otherwise they are pinned.
set fixedbase 1

# if 1, then a PD leaning column is generated
set PDcolumn 1

# This is the ratio of tributary load that goes to the wall. The rest goes to the leaning column 
set pTrib [expr 0.30] ;



# PD column area and Izz (summed up over all gravity columns plus 2*1/2 walls acting
# in the other direction)

# We are assuming about 2 gravity columns acting in the direction of the shear wall
set NcolPD 2

# Define column dimension (assuming b=h for columns)
# For the shear wall example, we assume 40x40 for all gravity columns, no matter the floor
set coldim [expr 0.4*$m]

#Calculate A and Izz of one column
set Ac [expr $coldim**2.*$m2]
set Iz [expr $coldim**4./12.*$m4]

# Initialize arrays for cross-sectional area and inertia A,Izz of the PD column
set AcolPD ""
set IcolPD ""

# Generate P-D column arrays
for {set i 1} {$i<=$Nstory} {incr i} {
	set i_1 [expr $i-1]
	lappend AcolPD [expr $Ac]; # will be multiplied by the number of columns per story
	lappend IcolPD [expr $Iz]

} 
