function cs = flipcscvn(cv)
%CSCVN `Natural' or periodic cubic spline curve.
%________________________________________________________________
% INPUT
%   cv : a cell array 1xN of 2D parametric spline produced by cscvn
% OUTPUT
%   cs : the exact same curve as cv, only now the x(t) and y(t)
%        are interchanged. Much easier than fitting again!
%________________________________________________________________
% This routine tackles a problem often encountered when using
% x2y.m, dxy2xy.m etc. Simply sometimes you want to look at
% the line having x or y as the independant variable. Instead
% of refitting, you simply flip the curve polynomials.
% (Last updated: September 3rd, 1999)
% Updated December 13th, 2004:  Now will work on cv being a cell array 
%                               with multiple curves.
% Copyright (c) 1999 by D.Vamvatsikos

% allocate space for a same size cell array
cs=cell(size(cv));
for R=1:length(cv)
   %// reverse the coordinates by changing the position of 
   %// coefficients of the relevant polynomial pieces
   
   [breaks,coefs]=ppbrk(cv{R});

   %// do the swapping of the rows of coefficients
   temp=coefs(2:2:size(coefs,1),:);
   coefs(2:2:size(coefs,1),:)=coefs(1:2:size(coefs,1),:);
   coefs(1:2:size(coefs,1),:)=temp;
   
   %// now put back "cv" using the old breaks and the new coefficients.
   cs{R}=ppmak(breaks,coefs,2);
end