function [flc,lowest_C]=get_flatline_capacity(svalues,dvalues,NCSa,biasedflag)
%function [flc]=get_flatline_capacity(svalues,dvalues,NCSa)
%
% This function will extract the flatline (Sa) capacity out of the
% IDA. Both the newer version (where NaNs and Infs are allowed in
% the dvalues) and the older version (where NCSa is contains the
% lowest NC point) are supported.
%_________________________________________________________________
%
%
%
%_________________________________________________________________
%
% Copyright (c) 2001 by D.Vamvatsikos
% Last updated: May 16th, 2001

% the default is not to allow biased estimates
if nargin<4, biasedflag=0; end
if nargin<3, NCSa=[]; end
if nargin<2, error('Need at least 2 inputs'); end

maxR=length(svalues);

%if isempty(NCSa)
 % NCSa=repmat(Inf,1,maxR);
%end
 
%keyboard

for i=1:maxR
  len=length(dvalues{i});
  % find the index of the lowest convergent point!
  lowest_C(i)=min([find(isnan(dvalues{i})|isinf(dvalues{i}))',...
		   len+1])-1;
  if lowest_C(i)==len
    % either non-collapsing structure, or this is an old-style IDA,
    % where the NC's are contained only as in NCSa
    if isempty(NCSa)
      % NCSa is not supplied. If the user believes that the
      % structure is still a collapsing one and he wants biased
      % (towards low Sas) estimates of flatline capacity, let him
      % have them.
      if biasedflag
	flc(i)=svalues{i}(lowest_C(i));
      else
	flc(i)=NaN;
      end
    else
      % if NCSa is supplied, then for a non-collapsing structure it
      % will be NaN, and the flc will come out NaN. Otherwise an
      % unbiased estimate will be provided below.
      flc(i)=0.5*(svalues{i}(lowest_C(i))+NCSa(i));
    end  
  else
    % all NC points are contained in svalues. Use the average of
    % the highest converging and the lowest non-converging Sa's to
    % get an unbiased estimate of flatline capacity.
    flc(i)=0.5*(svalues{i}(lowest_C(i))+svalues{i}(lowest_C(i)+1));
  end  
end;

