function [x]=iquantile(X,q)
% function [x]=iquantile(X,q)
% Works along the columns. Check that quantile(X,0.5)==median(X,0.5)
%-------------------------------------------------------------------
% produces quantiles for data. Matlab's prctile gives different results
% but this function is identical to the one in Splus!!
% INPUT
%   X : matrix NxM of samples
%   q : vector Kx1 of quantiles
% OUTPUT
%   x : matrix KxM  X-values that correspond to the 
%       given quantiles. Column-i contains the quantiles
%       of column-i of X
%-------------------------------------------------------------------
% NOTE : This function produces identical results with the quantile
% of Splus.
% CAUTION : This will not check for q(i) in [0,1]. 
% This is the user's responsibility!
% (Last updated June 15th, 1999)
% the only difference between this function and "quantile.m"  is
% the special treatment of NaN's. We assume the NaN's to be
% Inf's, e.g very large numbers and find quantiles's all along.
%
% Copyright (c) 1999 by D.Vamvatsikos



%// turn all NaN's to Inf's !!
X(find(isnan(X)))=inf;
%// sorthing places the Inf's in the upper end!
X=sort(X);
[N,M]=size(X);
% calculate index of corresponding quantile (+1 as 1st index is 1 not 0)
i=floor((N-1)*q+1);
% Calculate decimal fraction left out.
frac=(N-1)*q+1-i;
% Now if frac=0, then x=X(i,:), else interpolate linearly between 
% X(i,:) and X(i+1,:)
x=X(i,:)+(X(i+1,:)-X(i,:)).*repmat(frac,1,M);

%// now turn all remaining Inf's to NaN's (more useful this way)
%// as NaN is more stable than inf (inf-inf=NaN for example).
x(find(isinf(x)))=nan;
