function [T_periods] = getperiods_osees(anlsdir,exefile,infile,outdir)
% Will provide the eigenperiods of an opensees structure, assuming 
% the file is capable of understanding "analysistype==eigenvalue" and it
% outputs them in a file with "periods" in its name!! All my files do this.
%
% Example:
% getperiods_osees('\users\divamva\opensees\divamva\simple2Dframe',...
%                     '../openSees','generate2Dframe.tcl','.')
% anlsdir = directory where both opensees and the infile exist and the analysis
% takes place.
% infile = input filename
% exefile = opensees executable
% outdir = directory where the output goes.
%
% Updated: Oct 5, 2005
%       Added the option anls.exefile, which defines what openSees
%       executable to use (and where it resides).
% Updated 15/Feb/2010
%       Now works through the MatIDA_anlsfile.tcl as well. I have also kept the
%       older settings just to be sure. Slowly you must remove this
%       "_thfile" functionality from all opensees files.
% Updated 20/Sep/2012: Included true imultcpu functionality for multi-core
%         computers (running multiple instances on same computer). Also
%         removed double-quotes from filenames sent to opensees to be able
%         to include "-par ....' in the infile.
% Updated 12/Apr/2013: After testing on MacOS with Kishor it appears that
%         "dir" does not always switch to lower case. So I changed the
%         search pattern for the Periods.out file to "*eriods*.out"

currentdir=cd;
cd(anlsdir);

% works with newer files
write_MatIDA_paramfile(outdir,'MatIDA_anlsfile.tcl',0,'analysistype','eigenvalue');
% works with older files
write_MatIDA_paramfile(outdir,'MatIDA_thfile.tcl',0,'analysistype','eigenvalue',...
                       'GMdir','','GMfileX','','GMfactorX',1.5);

%fout=fopen('MatIDA_thfile.tcl','w');
% NOTE : FOR THIS TO WORK, THE ORIGINAL SETTING OF analysistype must happen
% before reading in MatIDA_thfile.tcl. But since this file is only read
% if the analysis is dynamic (in my files at least) this is OK!!
%fprintf(fout,'set analysistype "eigenvalue"\n');
%fprintf(fout,'set GMdir ""\n');
%fprintf(fout,'set GMfileX ""\n');
%fprintf(fout,'set GMfactorX %g\n',1);
%fclose(fout);



% Note that you need the "" in general. If path information is included
% especially something like "..", then simply >> ! ../opensees << will not
% work! On the other hand >> ! "../opensees" always works!
%eval(sprintf('!"%s" %s >screendump',exefile,infile));
eval(sprintf('!"%s" %s > "%s"',exefile,infile,fullfile(outdir,'screendump')));

% for compatibility with older versions, remove the anlsfile,
% otherwise all my runIDA routines will fail.
delete(fullfile(outdir,'MatIDA_anlsfile.tcl'));


cd(outdir);
%periodsfile=dir('*periods*.out');
periodsfile=dir('*eriods*.out');
%IF more than one or no such file exists, STOP
if length(periodsfile)~=1, 
   error('Cannot locate periods file'); 
else
   T_periods=dlmread(periodsfile.name,' ');
end