function [drift,tout]=postproc_osees2Di_frame_Shear_Wall
% [drift,tout]=postproc_osees2Di_frame_Shear_Wall
% Function for postprocessing the IDA results of the shear wall
% It has been designed to be called from within anlsproc_oseesNDi.m to do the 
% post processing after each single dynamic run has been performed. 
%________________________________________________________________________________
% INPUT
% none
% -------------------------------------------------------------------------------
% OUTPUT
% drift            : maximum interstory drift ratio over the height of the
%                    building in each run
% tout             : a structure containing all the output taken from the timehistories
%_____________________________________________________________________________________
%
%
% Created Sep 22,2005: The file postproc_osees3Di_bridge.m was used as
%         a template! It has been updated as well, so that it doesn't
%         produce errors if "-time" is specified or not at the recorders!
% Updated 05/Oct/2010: Now OpenSees 2.2 does not produce the extra space at
%         the end of each output line. So you do not need the -1 when
%         defining icol below.
% Modified 08/07/2019: post-processing IDA results of the shear wall
%
%

%  maximum interstory drift ratio
all_idrx_files =dir('idr4f_*x.out');
%If the files are named idr_01x, idr_02x (instead of idr_1x and idr2x) 
% then they will be sorted in the right order as columns increase (left to right)!
for i=1:length(all_idrx_files)
   tdrx=dlmread(all_idrx_files(i).name,' ');
   % use this trick to make sure you are reading the right column,
   % regardless of whether the output contains a time-column or not
   icol=size(tdrx,2);
   maxidr_mx(i)=max(abs(tdrx(:,icol)));
end

% roof drift ratio
single_rdrx_file=dir('roofdrx.out');
if ~isempty(single_rdrx_file)
   tdrx=dlmread(single_rdrx_file.name,' ');
   icol=size(tdrx,2);   
   maxrdrx=max(abs(tdrx(:,icol)));
end

drift=max(maxidr_mx);


% store the results in the tout structure
tout.maxidr_mx=maxidr_mx;
tout.maxrdrx=maxrdrx;



